@@ -1,6 +1,6 @@
 package Treex::Block::Read::BaseReader;
 BEGIN {
-  $Treex::Block::Read::BaseReader::VERSION = '0.06513_1';
+  $Treex::Block::Read::BaseReader::VERSION = '0.06903_1';
 }
 use Moose;
 use Treex::Core::Common;
@@ -13,26 +13,16 @@ sub next_document {
     return log_fatal "method next_document must be overriden in " . ref($self);
 }
 
-has selector => ( isa => 'Selector', is => 'ro', default => '' );
-
-has filenames => (
-    isa           => 'ArrayRef[Str]',
-    is            => 'ro',
-    lazy_build    => 1,
-    documentation => 'array of filenames to be loaded;'
-        . ' automatically initialized from the attributes "from" and "filelist"',
-);
+has selector => ( isa => 'Treex::Type::Selector', is => 'ro', default => q{} );
 
 has from => (
-    isa           => 'Str',
+    isa           => 'Treex::Core::Files',
     is            => 'ro',
-    documentation => 'space or comma separated list of filenames to be loaded',
-);
-
-has filelist => (
-    isa           => 'Str',
-    is            => 'ro',
-    documentation => 'a file that contains the list of filenames to be loaded, one per line',
+    coerce        => 1,
+    handles       => [qw(current_filename file_number _set_file_number)],
+    documentation => 'arrayref of filenames to be loaded, '
+        . 'coerced from a space or comma separated list of filenames, '
+        . 'see POD for details',
 );
 
 has file_stem => (
@@ -41,15 +31,6 @@ has file_stem => (
     documentation => 'how to name the loaded documents',
 );
 
-has file_number => (
-    isa           => 'Int',
-    is            => 'ro',
-    writer        => '_set_file_number',
-    default       => 0,
-    init_arg      => undef,
-    documentation => 'Number of input files loaded so far.',
-);
-
 has is_one_doc_per_file => (
     is      => 'rw',
     isa     => 'Bool',
@@ -58,41 +39,6 @@ has is_one_doc_per_file => (
 
 has _file_numbers => ( is => 'rw', default => sub { {} } );
 
-sub _build_filenames {
-    my $self = shift;
-
-    log_fatal "Parameters 'from' or 'filelist' must be defined!" if !defined $self->from && !defined $self->filelist;
-
-    my $filenames = [];
-
-    # add all files in the 'from' parameter to the list (avoid adding STDIN if filelist is set)
-    if ( $self->from && ( !$self->filelist || $self->from ne '-' ) ) {
-        push @{$filenames}, split( /[ ,]+/, $self->from );
-    }
-
-    # add all files from the filelist to the list
-    if ( $self->filelist ) {
-        my @list = read_file( $self->filelist );
-        log_fatal 'File list ' . $self->filelist . ' cannot be loaded!' if @list == 1 && !defined( $list[0] );
-        @list = map {
-            local $_ = $_;
-            $_ =~ s/\s*\r?\n$//;
-            $_ =~ s/^\s*//;
-            $_
-        } @list;    # remove EOL chars, trim
-        push @{$filenames}, @list;
-    }
-
-    # return the resulting list
-    return $filenames;
-}
-
-sub current_filename {
-    my ($self) = @_;
-    return if $self->file_number == 0 || $self->file_number > @{ $self->filenames };
-    return $self->filenames->[ $self->file_number - 1 ];
-}
-
 sub is_next_document_for_this_job {
     my ($self) = @_;
     return 1 if !$self->jobindex;
@@ -132,7 +78,7 @@ sub new_document {
     }
 
     if ( $self->is_one_doc_per_file && !$self->file_stem ) {
-        $args{file_number} = '';
+        $args{file_number} = q{};
     }
     else {
         my $num = $self->_file_numbers->{$stem};
@@ -145,12 +91,18 @@ sub new_document {
     }
 
     $self->_set_doc_number( $self->doc_number + 1 );
-    return Treex::Core::Document->new( \%args );
+
+    my $document = Treex::Core::Document->new( \%args );
+    if ( defined $load_from && $load_from =~ /\.gz$/ ) {
+        $document->set_compress(1);
+    }
+
+    return $document;
 }
 
 sub number_of_documents {
     my $self = shift;
-    return $self->is_one_doc_per_file ? scalar @{ $self->filenames } : undef;
+    return $self->is_one_doc_per_file ? $self->from->number_of_files : undef;
 }
 
 after 'restart' => sub {
@@ -168,7 +120,7 @@ Treex::Block::Read::BaseReader - abstract ancestor for document readers
 
 =head1 VERSION
 
-version 0.06513_1
+version 0.06903_1
 
 =head1 DESCRIPTION
 
