@@ -1,6 +1,6 @@
 package Treex::Core::TredView;
 BEGIN {
-  $Treex::Core::TredView::VERSION = '0.06513_1';
+  $Treex::Core::TredView::VERSION = '0.06903_1';
 }
 
 # planned to be used from contrib.mac of tred's extensions
@@ -11,6 +11,7 @@ use Treex::Core::TredView::TreeLayout;
 use Treex::Core::TredView::Labels;
 use Treex::Core::TredView::Styles;
 use Treex::Core::TredView::Vallex;
+use Treex::Core::Types;
 use List::Util qw(first);
 
 has 'grp'       => ( is => 'rw' );
@@ -48,6 +49,7 @@ has fast_loading => (
 );
 
 has 'clause_collapsing' => ( is => 'rw', isa => 'Bool', default => 0 );
+has 'show_alignment'    => ( is => 'rw', isa => 'Bool', default => 1 );
 
 sub _spread_nodes {
     my ( $self, $node ) = @_;
@@ -64,7 +66,7 @@ sub _spread_nodes {
         push @lower, @buf;
     }
     $right += $pos;
-    return ( 0, $node ) unless @lower;
+    return ( 0, $node ) if !@lower;
 
     my $mid;
     if ( scalar( $node->children ) == 1 ) {
@@ -94,7 +96,8 @@ sub get_nodelist_hook {
         my $label = $self->tree_layout->get_tree_label($tree);
         my @nodes;
         if ( $tree->get_layer eq 'p' ) {
-            ( my $foo, @nodes ) = $self->_spread_nodes($tree);
+            @nodes = $self->_spread_nodes($tree);
+            shift @nodes;
         }
         elsif ( $tree->does('Treex::Core::Node::Ordered') ) {
             @nodes = $tree->get_descendants( { add_self => 1, ordered => 1 } );
@@ -257,7 +260,7 @@ sub value_line_doubleclick_hook {
 
 # --------------- PRECOMPUTING VISUALIZATION (node labels, styles, coreference links, groups...) ---
 
-my @layers = qw(a t p n);
+my @layers = map {lc} Treex::Core::Types::layers();
 
 # To be run only once when the file is opened. Tree depths never change.
 sub precompute_tree_depths {
@@ -483,7 +486,7 @@ sub tnode_hint {
 
 sub nnode_hint {
     my ( $self, $node ) = @_;
-    return undef;
+    return;
 }
 
 sub pnode_hint {
@@ -525,7 +528,7 @@ sub node_style_hook {
     }
 
     # alignment
-    if ( my $links = $node->attr('alignment') ) {
+    if ( $self->show_alignment and my $links = $node->attr('alignment') ) {
         foreach my $link (@$links) {
             push @target_ids,  $link->{'counterpart.rf'};
             push @arrow_types, 'alignment';
@@ -626,6 +629,11 @@ sub toggle_clause_collapsing {
     }
 }
 
+sub toggle_alignment {
+    my $self = shift;
+    $self->show_alignment( not $self->show_alignment );
+}
+
 1;
 
 __END__
@@ -638,7 +646,7 @@ Treex::Core::TredView - visualization of Treex files in TrEd
 
 =head1 VERSION
 
-version 0.06513_1
+version 0.06903_1
 
 =head1 DESCRIPTION
 
