@@ -1,6 +1,6 @@
 package Treex::Core::WildAttr;
 BEGIN {
-  $Treex::Core::WildAttr::VERSION = '0.06513_1';
+  $Treex::Core::WildAttr::VERSION = '0.06903_1';
 }
 use Moose::Role;
 
@@ -78,12 +78,13 @@ __END__
 
 =head1 NAME
 
-Treex::Core::WildAttr
+Treex::Core::WildAttr - role for arbitrary atributes of Treex objects
 
 =head1 VERSION
 
-version 0.06513_1
+version 0.06903_1
 
+=for test_synopsis my ($node, $value);
 =head1 SYNOPSIS
 
   $node->wild->{name_of_my_new_attribute} = $value;
